@@ -61,13 +61,14 @@ class RequestedAxis(FrozenClass):
         is_step=False,
         noct=None,
         corr_values=None,
+        is_components=False,
         init_dict=None,
         init_str=None,
     ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
             for SciDataTool type, -1 will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
+        - __init__ (init_dict = d) d must be a dictionary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
@@ -111,6 +112,8 @@ class RequestedAxis(FrozenClass):
                 noct = init_dict["noct"]
             if "corr_values" in list(init_dict.keys()):
                 corr_values = init_dict["corr_values"]
+            if "is_components" in list(init_dict.keys()):
+                is_components = init_dict["is_components"]
         # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.name = name
@@ -129,6 +132,7 @@ class RequestedAxis(FrozenClass):
         self.is_step = is_step
         self.noct = noct
         self.corr_values = corr_values
+        self.is_components = is_components
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
@@ -188,6 +192,7 @@ class RequestedAxis(FrozenClass):
             + linesep
             + linesep
         )
+        RequestedAxis_str += "is_components = " + str(self.is_components) + linesep
         return RequestedAxis_str
 
     def __eq__(self, other):
@@ -227,11 +232,15 @@ class RequestedAxis(FrozenClass):
             return False
         if not array_equal(other.corr_values, self.corr_values):
             return False
+        if other.is_components != self.is_components:
+            return False
         return True
 
-    def compare(self, other, name="self"):
+    def compare(self, other, name="self", ignore_list=None):
         """Compare two objects and return list of differences"""
 
+        if ignore_list is None:
+            ignore_list = list()
         if type(other) != type(self):
             return ["type(" + name + ")"]
         diff_list = list()
@@ -267,6 +276,10 @@ class RequestedAxis(FrozenClass):
             diff_list.append(name + ".noct")
         if not array_equal(other.corr_values, self.corr_values):
             diff_list.append(name + ".corr_values")
+        if other._is_components != self._is_components:
+            diff_list.append(name + ".is_components")
+        # Filter ignore differences
+        diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
 
     def __sizeof__(self):
@@ -291,11 +304,16 @@ class RequestedAxis(FrozenClass):
         S += getsizeof(self.is_step)
         S += getsizeof(self.noct)
         S += getsizeof(self.corr_values)
+        S += getsizeof(self.is_components)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
@@ -309,14 +327,32 @@ class RequestedAxis(FrozenClass):
         if self.values is None:
             RequestedAxis_dict["values"] = None
         else:
-            RequestedAxis_dict["values"] = self.values.tolist()
+            if type_handle_ndarray == 0:
+                RequestedAxis_dict["values"] = self.values.tolist()
+            elif type_handle_ndarray == 1:
+                RequestedAxis_dict["values"] = self.values.copy()
+            elif type_handle_ndarray == 2:
+                RequestedAxis_dict["values"] = self.values
+            else:
+                raise Exception(
+                    "Unknown type_handle_ndarray: " + str(type_handle_ndarray)
+                )
         RequestedAxis_dict["indices"] = (
             self.indices.copy() if self.indices is not None else None
         )
         if self.input_data is None:
             RequestedAxis_dict["input_data"] = None
         else:
-            RequestedAxis_dict["input_data"] = self.input_data.tolist()
+            if type_handle_ndarray == 0:
+                RequestedAxis_dict["input_data"] = self.input_data.tolist()
+            elif type_handle_ndarray == 1:
+                RequestedAxis_dict["input_data"] = self.input_data.copy()
+            elif type_handle_ndarray == 2:
+                RequestedAxis_dict["input_data"] = self.input_data
+            else:
+                raise Exception(
+                    "Unknown type_handle_ndarray: " + str(type_handle_ndarray)
+                )
         RequestedAxis_dict["operation"] = self.operation
         RequestedAxis_dict["index"] = self.index
         RequestedAxis_dict["transform"] = self.transform
@@ -324,13 +360,32 @@ class RequestedAxis(FrozenClass):
         if self.rebuild_indices is None:
             RequestedAxis_dict["rebuild_indices"] = None
         else:
-            RequestedAxis_dict["rebuild_indices"] = self.rebuild_indices.tolist()
+            if type_handle_ndarray == 0:
+                RequestedAxis_dict["rebuild_indices"] = self.rebuild_indices.tolist()
+            elif type_handle_ndarray == 1:
+                RequestedAxis_dict["rebuild_indices"] = self.rebuild_indices.copy()
+            elif type_handle_ndarray == 2:
+                RequestedAxis_dict["rebuild_indices"] = self.rebuild_indices
+            else:
+                raise Exception(
+                    "Unknown type_handle_ndarray: " + str(type_handle_ndarray)
+                )
         RequestedAxis_dict["is_step"] = self.is_step
         RequestedAxis_dict["noct"] = self.noct
         if self.corr_values is None:
             RequestedAxis_dict["corr_values"] = None
         else:
-            RequestedAxis_dict["corr_values"] = self.corr_values.tolist()
+            if type_handle_ndarray == 0:
+                RequestedAxis_dict["corr_values"] = self.corr_values.tolist()
+            elif type_handle_ndarray == 1:
+                RequestedAxis_dict["corr_values"] = self.corr_values.copy()
+            elif type_handle_ndarray == 2:
+                RequestedAxis_dict["corr_values"] = self.corr_values
+            else:
+                raise Exception(
+                    "Unknown type_handle_ndarray: " + str(type_handle_ndarray)
+                )
+        RequestedAxis_dict["is_components"] = self.is_components
         # The class name is added to the dict for deserialisation purpose
         RequestedAxis_dict["__class__"] = "RequestedAxis"
         return RequestedAxis_dict
@@ -354,6 +409,7 @@ class RequestedAxis(FrozenClass):
         self.is_step = None
         self.noct = None
         self.corr_values = None
+        self.is_components = None
 
     def _get_name(self):
         """getter of name"""
@@ -672,3 +728,21 @@ class RequestedAxis(FrozenClass):
         :Type: ndarray
         """,
     )
+
+    def _get_is_components(self):
+        """getter of is_components"""
+        return self._is_components
+
+    def _set_is_components(self, value):
+        """setter of is_components"""
+        check_var("is_components", value, "bool")
+        self._is_components = value
+
+    is_components = property(
+        fget=_get_is_components,
+        fset=_set_is_components,
+        doc=u"""To indicate if the values are strings
+
+        :Type: bool
+        """,
+    )
