@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from SciDataTool.Functions.Plot.plot_4D import plot_4D
 from SciDataTool.Functions.Plot.plot_3D import plot_3D
 from SciDataTool.Functions.Plot import unit_dict, norm_dict, axes_dict
@@ -31,7 +29,7 @@ def plot_3D_Data(
     z_range=None,
     is_auto_ticks=True,
     is_auto_range=True,
-    is_2D_view=False,
+    is_2D_view=True,
     is_contour=False,
     is_same_size=False,
     N_stem=100,
